@@ -52,7 +52,6 @@ from strawberry.extensions.field_extension import build_field_extension_resolver
 from strawberry.relay.types import GlobalID
 from strawberry.schema.types.scalar import (
     DEFAULT_SCALAR_REGISTRY,
-    _get_scalar_definition,
     _make_scalar_type,
 )
 from strawberry.types.arguments import StrawberryArgument, convert_arguments
@@ -249,35 +248,38 @@ class GraphQLCoreConverter:
         self,
         config: StrawberryConfig,
         scalar_overrides: Mapping[object, ScalarWrapper | ScalarDefinition],
+        scalar_map: Mapping[object, ScalarDefinition],
         get_fields: Callable[[StrawberryObjectDefinition], list[StrawberryField]],
     ) -> None:
         self.type_map: dict[str, ConcreteType] = {}
         self.config = config
-        self.scalar_registry = self._get_scalar_registry(scalar_overrides)
+        self.scalar_registry = self._get_scalar_registry(scalar_overrides, scalar_map)
         self.get_fields = get_fields
 
     def _get_scalar_registry(
         self,
         scalar_overrides: Mapping[object, ScalarWrapper | ScalarDefinition],
+        scalar_map: Mapping[object, ScalarDefinition],
     ) -> Mapping[object, ScalarWrapper | ScalarDefinition]:
-        scalar_registry = {**DEFAULT_SCALAR_REGISTRY}
+        scalar_registry: dict[object, ScalarWrapper | ScalarDefinition] = {
+            **DEFAULT_SCALAR_REGISTRY
+        }
 
         global_id_name = "GlobalID" if self.config.relay_use_legacy_global_id else "ID"
 
-        scalar_registry[GlobalID] = _get_scalar_definition(
-            scalar(
-                GlobalID,
-                name=global_id_name,
-                description=GraphQLID.description,
-                parse_value=lambda v: v,
-                serialize=str,
-                specified_by_url=("https://relay.dev/graphql/objectidentification.htm"),
-            )
+        scalar_registry[GlobalID] = scalar(
+            name=global_id_name,
+            description=GraphQLID.description,
+            parse_value=lambda v: v,
+            serialize=str,
+            specified_by_url="https://relay.dev/graphql/objectidentification.htm",
         )
 
+        if scalar_map:
+            scalar_registry.update(scalar_map)
+
         if scalar_overrides:
-            # TODO: check that the overrides are valid
-            scalar_registry.update(scalar_overrides)  # type: ignore
+            scalar_registry.update(scalar_overrides)
 
         return scalar_registry
 
